<?php
/**
 * Sample implementation of the Custom Header feature
 *
 * You can add an optional custom header image to header.php like so ...
 *
	<?php the_header_image_tag(); ?>
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 * @package Personal_Trainer
 */

// For registration of custom-header, check customizer/header-background-color.php


if ( ! function_exists( 'personaltrainer_header_style' ) ) :
	/**
	 * Styles the header image and text displayed on the blog.
	 *
	 * @see personaltrainer_custom_header_setup().
	 */
	function personaltrainer_header_style() {
		$header_text_color = get_header_textcolor();

		$header_image = personaltrainer_featured_overall_image();

	    if ( $header_image ) : ?>
	        <style type="text/css" rel="header-image">
	            .custom-header:before {
	                background-image: url( <?php echo esc_url( $header_image ); ?>);
					background-position: center;
					background-repeat: no-repeat;
					background-size: cover;
	            }
	        </style>
	    <?php
	    endif;

		/*
		 * If no custom options for text are set, let's bail.
		 * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: add_theme_support( 'custom-header' ).
		 */
		if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) {
			return;
		}

		// If we get this far, we have custom styles. Let's do this.
		?>
		<style type="text/css">
		<?php
		// Has the text been hidden?
		if ( ! display_header_text() ) :
		?>
			.site-title,
			.site-description {
				position: absolute;
				clip: rect(1px, 1px, 1px, 1px);
			}
		<?php
			// If the user has set a custom color for the text use that.
			else :
		?>
			.site-title a,
			.site-description {
				color: #<?php echo esc_attr( $header_text_color ); ?>;
			}
		<?php endif; ?>
		</style>
		<?php
	}
endif;

if ( ! function_exists( 'personaltrainer_featured_image' ) ) :
	/**
	 * Template for Featured Header Image from theme options
	 *
	 * To override this in a child theme
	 * simply create your own personaltrainer_featured_image(), and that function will be used instead.
	 *
	 * @since Personal Trainer 0.1
	 */
	function personaltrainer_featured_image() {
		$thumbnail = is_front_page() ? 'personaltrainer-header-inner' : 'personaltrainer-slider';

		if ( is_post_type_archive( 'jetpack-testimonial' ) ) {
			$jetpack_options = get_theme_mod( 'jetpack_testimonials' );

			if ( isset( $jetpack_options['featured-image'] ) && '' !== $jetpack_options['featured-image'] ) {
				return wp_get_attachment_image_src( (int) $jetpack_options['featured-image'], $thumbnail );
			} else {
				return false;
			}
		} elseif ( is_post_type_archive( 'jetpack-portfolio' ) ) {
			$jetpack_portfolio_featured_image = get_option( 'jetpack_portfolio_featured_image' );

			if ( '' !== $jetpack_portfolio_featured_image ) {
				return wp_get_attachment_image_src( (int) $jetpack_portfolio_featured_image, $thumbnail );
			} else {
				return false;
			}
		} elseif ( is_header_video_active() && has_header_video() ) {
			return true;
		} else {
			return get_header_image();
		}
	} // personaltrainer_featured_image
endif;

if ( ! function_exists( 'personaltrainer_featured_page_post_image' ) ) :
	/**
	 * Template for Featured Header Image from Post and Page
	 *
	 * To override this in a child theme
	 * simply create your own personaltrainer_featured_imaage_pagepost(), and that function will be used instead.
	 *
	 * @since Personal Trainer 0.1
	 */
	function personaltrainer_featured_page_post_image() {
		if ( ! has_post_thumbnail() ) {
			return personaltrainer_featured_image();
		}

		$thumbnail = is_front_page() ? 'personaltrainer-header-inner' : 'personaltrainer-slider';

		return get_the_post_thumbnail_url( get_the_id(), $thumbnail );
	} // personaltrainer_featured_page_post_image
endif;

if ( ! function_exists( 'personaltrainer_featured_overall_image' ) ) :
	/**
	 * Template for Featured Header Image from theme options
	 *
	 * To override this in a child theme
	 * simply create your own personaltrainer_featured_pagepost_image(), and that function will be used instead.
	 *
	 * @since Personal Trainer 0.1
	 */
	function personaltrainer_featured_overall_image() {
		global $post, $wp_query;
		$enable = get_theme_mod( 'personaltrainer_header_media_option', 'exclude-home-page-post' );

		// Get Page ID outside Loop
		$page_id = absint( $wp_query->get_queried_object_id() );

		$page_for_posts = absint( get_option( 'page_for_posts' ) );

		// Check Enable/Disable header image in Page/Post Meta box
		if ( is_singular() ) {
			//Individual Page/Post Image Setting
			$individual_featured_image = get_post_meta( $post->ID, 'personaltrainer-header-image', true );

			if ( 'disable' === $individual_featured_image || ( 'default' === $individual_featured_image && 'disable' === $enable ) ) {
				return;
			} elseif ( 'enable' == $individual_featured_image && 'disable' === $enable ) {
				return personaltrainer_featured_page_post_image();
			}
		}

		// Check Homepage
		if ( 'homepage' === $enable ) {
			if ( is_front_page() || ( is_home() && $page_for_posts !== $page_id ) ) {
				return personaltrainer_featured_image();
			}
		} elseif ( 'exclude-home' === $enable ) {
			// Check Excluding Homepage
			if ( is_front_page() || ( is_home() && $page_for_posts !== $page_id ) ) {
				return false;
			} else {
				return personaltrainer_featured_image();
			}
		} elseif ( 'exclude-home-page-post' === $enable ) {
			if ( is_front_page() || ( is_home() && $page_for_posts !== $page_id ) ) {
				return false;
			} elseif ( is_singular() ) {
				return personaltrainer_featured_page_post_image();
			} else {
				return personaltrainer_featured_image();
			}
		} elseif ( 'entire-site' === $enable ) {
			// Check Entire Site
			return personaltrainer_featured_image();
		} elseif ( 'entire-site-page-post' === $enable ) {
			// Check Entire Site (Post/Page)
			if ( is_singular() || ( is_home() && $page_for_posts === $page_id ) ) {
				return personaltrainer_featured_page_post_image();
			} else {
				return personaltrainer_featured_image();
			}
		} elseif ( 'pages-posts' === $enable ) {
			// Check Page/Post
			if ( is_singular() ) {
				return personaltrainer_featured_page_post_image();
			}
		}

		return false;
	} // personaltrainer_featured_overall_image
endif;

if ( ! function_exists( 'personaltrainer_header_media_text' ) ):
	/**
	 * Display Header Media Text
	 *
	 * @since Personal Trainer Pro 1.0
	 */
	function personaltrainer_header_media_text() {
		if ( ! personaltrainer_has_header_media_text() ) {
			// Bail early if header media text is disabled on front page
			return false;
		}
		?>
		<div class="entry-container">
			<header class="entry-header">
				<h1 class="entry-title">
					<?php personaltrainer_header_title(); ?>
				</h1>
				<?php if ( is_front_page() ) :
					$header_media_title    = get_theme_mod( 'personaltrainer_header_media_title' );
					$header_media_text     = get_theme_mod( 'personaltrainer_header_media_text' );
					$header_media_url      = get_theme_mod( 'personaltrainer_header_media_url', '' );
					$header_media_url_text = get_theme_mod( 'personaltrainer_header_media_url_text' );
				?>
				<div class="entry-summary">
					<p><?php echo wp_kses_post( $header_media_text ); ?></p>
				</div>

					<?php if ( $header_media_url ) : ?>
					<a href="<?php echo esc_url( $header_media_url ); ?>" target="<?php echo get_theme_mod( 'personaltrainer_header_url_target' ) ? '_blank' : '_self'; ?>" class="more-link"><?php echo esc_html( $header_media_url_text ); ?><span class="screen-reader-text"><?php echo wp_kses_post( $header_media_title ); ?></span></a>
					<?php endif; ?>
				<?php endif; ?>
			</header>

			<?php get_template_part( 'template-parts/header/breadcrumb' ); ?>
		</div> <!-- entry-container -->
		<?php
	} // personaltrainer_header_media_text.
endif;

if ( ! function_exists( 'personaltrainer_has_header_media_text' ) ):
	/**
	 * Return Header Media Text fro front page
	 *
	 * @since Personal Trainer 0.1
	 */
	function personaltrainer_has_header_media_text() {
		$header_media_title    = get_theme_mod( 'personaltrainer_header_media_title' );
		$header_media_text     = get_theme_mod( 'personaltrainer_header_media_text' );
		$header_media_url      = get_theme_mod( 'personaltrainer_header_media_url', '' );
		$header_media_url_text = get_theme_mod( 'personaltrainer_header_media_url_text' );

		if ( is_front_page() && ! $header_media_title && ! $header_media_text && ! $header_media_url && ! $header_media_url_text ) {
			// Bail early if header media text is disabled
			return false;
		}

		return true;
	} // personaltrainer_has_header_media_text.
endif;
